OC.L10N.register(
    "files",
    {
    "Download" : "ဒေါင်းလုတ်",
    "Files" : "ဖိုင်များ",
    "Invalid path" : "လမ်း‌ေြကာင်းမှား"
},
"nplurals=1; plural=0;");
